@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2015 Canonical, Ltd.
+ * Copyright 2015 Canonical Ltd.
+ * Copyright 2021 Robert Tari
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -13,7 +14,9 @@
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Author: Xavi Garcia <xavi.garcia.mena@canonical.com>
+ * Authors:
+ *         Xavi Garcia <xavi.garcia.mena@canonical.com>
+ *         Robert Tari <robert@tari.in>
  */
 
 #include "indicator-sound-test-base.h"
@@ -176,18 +179,20 @@ bool IndicatorSoundTestBase::clearGSettingsPlayers()
 
 bool IndicatorSoundTestBase::resetAllowAmplifiedVolume()
 {
+#if LOMIRI_FEATURES_ENABLED
     QProcess proc;
 
     proc.start("gsettings", QStringList()
                                 << "reset"
-#ifdef HAS_UBUNTU_SOUND_SCHEMA
-                                << "com.ubuntu.sound"
-#else
-                                << "org.ayatana.sound"
-#endif
+
+                                << "com.lomiri.sound"
+
                                 << "allow-amplified-volume");
 
     return runProcess(proc);
+#else
+    return TRUE;
+#endif
 }
 
 bool IndicatorSoundTestBase::runProcess(QProcess& proc)
@@ -419,7 +424,7 @@ lomiri::gmenuharness::MenuItemMatcher IndicatorSoundTestBase::volumeSlider(doubl
             .double_attribute("min-value", 0.0)
             .double_attribute("max-value", 1.0)
             .double_attribute("step", 0.01)
-            .string_attribute("x-ayatana-type", "org.ayatana.unity.slider")
+            .string_attribute("x-ayatana-type", "org.ayatana.indicator.slider")
             .themed_icon("max-icon", {"audio-volume-high-panel", "audio-volume-high", "audio-volume", "audio"})
             .themed_icon("min-icon", {"audio-volume-low-zero-panel", "audio-volume-low-zero", "audio-volume-low", "audio-volume", "audio"})
             .pass_through_double_attribute("action", volume);
@@ -433,7 +438,7 @@ lomiri::gmenuharness::MenuItemMatcher IndicatorSoundTestBase::micSlider(double v
             .double_attribute("min-value", 0.0)
             .double_attribute("max-value", 1.0)
             .double_attribute("step", 0.01)
-            .string_attribute("x-ayatana-type", "org.ayatana.unity.slider")
+            .string_attribute("x-ayatana-type", "org.ayatana.indicator.slider")
             .themed_icon("max-icon", {"audio-input-microphone-high-panel", "audio-input-microphone-high", "audio-input-microphone", "audio-input", "audio"})
             .themed_icon("min-icon", {"audio-input-microphone-low-zero-panel", "audio-input-microphone-low-zero", "audio-input-microphone-low", "audio-input-microphone", "audio-input", "audio"})
             .pass_through_double_attribute("action", volume);
@@ -529,9 +534,10 @@ void IndicatorSoundTestBase::initializeAccountsInterface()
         auto userPath = userResp.value().path();
         if (userPath != "")
         {
-            std::unique_ptr<AccountsSoundInterface> soundInterface(new AccountsSoundInterface("org.freedesktop.Accounts",
+            // This silences cppcheck, but let's leave it here in case we actually need it
+            /*std::unique_ptr<AccountsSoundInterface> soundInterface(new AccountsSoundInterface("org.freedesktop.Accounts",
                                                                     userPath,
-                                                                    dbusTestRunner.systemConnection(), 0));
+                                                                    dbusTestRunner.systemConnection(), 0));*/
 
             accounts_interface_.reset(new DBusPropertiesInterface("org.freedesktop.Accounts",
                                                                 userPath,
@@ -641,13 +647,13 @@ void IndicatorSoundTestBase::checkVolumeNotification(double volume, QString cons
     QVariantMap hints;
     ASSERT_TRUE(qDBusArgumentToMap(args.at(6), hints));
     ASSERT_TRUE(hints.contains("value"));
-    ASSERT_TRUE(hints.contains("x-canonical-non-shaped-icon"));
-    ASSERT_TRUE(hints.contains("x-canonical-value-bar-tint"));
+    ASSERT_TRUE(hints.contains("x-lomiri-non-shaped-icon"));
+    ASSERT_TRUE(hints.contains("x-lomiri-value-bar-tint"));
     ASSERT_TRUE(hints.contains("x-canonical-private-synchronous"));
 
     EXPECT_EQ(volume*100, hints["value"]);
-    EXPECT_EQ(true, hints["x-canonical-non-shaped-icon"]);
-    EXPECT_EQ(isLoud, hints["x-canonical-value-bar-tint"]);
+    EXPECT_EQ(true, hints["x-lomiri-non-shaped-icon"]);
+    EXPECT_EQ(isLoud, hints["x-lomiri-value-bar-tint"]);
     EXPECT_EQ(true, hints["x-canonical-private-synchronous"]);
 }
 
@@ -1003,8 +1009,6 @@ QVariantList IndicatorSoundTestBase::getActionValue(QString const &action)
 
 QStringList IndicatorSoundTestBase::getRootIconValue(bool *isValid)
 {
-    QString result = 0;
-
     QVariantList varList = getActionValue("root");
     if (isValid != nullptr)
     {
